module StudioGame
  require_relative 'player'
  require_relative 'die'
  require_relative 'game_turn'
  require_relative 'treasure_trove'


  class Game
    attr_accessor :title, :players_array

    def initialize(title)
        @title = title
        @players_array = []
    end

    def add_player(player)
        @players_array.push(player)
    end

    def play(rounds)
      puts "There are #{@players_array.length} in #{@name}"

      1.upto(rounds) do |round_number|
          puts "\nRound #{round_number}:"
          @players_array.each do |player|
            GameTurn.take_turn(player)
            puts player
          end
      end

      treasures = TreasureTrove::TREASURES

      puts "\nThere are #{treasures.length} treasures to be found:"
      treasures.each do |treasure|
        puts "A #{treasure.name} is worth #{treasure.points} points"
      end
    end

    def print_name_and_stats(player)
      puts "#{player.name} (#{player.health})"
    end

    def print_stats
      strong_players = @players_array.select {|player| player.strong?}
      wimpy_players = @players_array.reject {|player| player.strong?}

      puts "\n#{@title} Statistics:"

      puts "\n#{strong_players.count} strong players:"
      strong_players.each do |player|
        print_name_and_stats(player)
      end

      puts "\n#{wimpy_players.count} wimpy_players:"
      wimpy_players.each do |player|
        print_name_and_stats(player)
      end

      puts "\n#{@title} High Score:"
      @players_array.sort.each do |player|
        puts high_score_entry(player)
      end

      @players_array.each do |player|
            puts "\n#{player.name}'s point totals:"
            puts "#{player.points} grand total points"
      end

      @players_array.sort.each do |player|
        puts "\n#{player.name}'s points totals:"
        player.each_found_treasure do |treasure|
          puts "#{treasure.points} total #{treasure.name} points"
        end
        puts "#{player.points} grand total points"
      end
    end

    def load_players(filename)
      File.readlines(filename).each do |line|
       add_player(Player.from_csv(line))
      end
    end

    def save_high_scores(to_file="high_scores.txt")
      File.open(to_file, "w") do |file|
        file.puts "#{@title} High Scores:"
        @players_array.sort.each do |player|
          file.puts high_score_entry(player)
        end
      end
    end

    def high_score_entry(player)
      formatted_name = player.name.ljust(20, '.')
      "#{formatted_name} #{player.score}"
    end
  end
end
