module StudioGame
  require_relative 'treasure_trove.rb'
  require_relative 'playable'

  class Player
    include Playable
    attr_accessor :name
    attr_reader :health

    def initialize(name, health=100)
      @name = name.capitalize
      @health = health
      @found_treasures = Hash.new(0)
    end

    def to_s
      "I'm #{@name} with a health of #{@health} and a score of #{score}."
    end

    def score
      @health + points
    end

    def <=>(other)
      other.score <=> score
    end

    def found_treasure(treasure)
      @found_treasures[treasure.name] += treasure.points
      puts "#{@name} found a #{treasure.name} worth #{treasure.points}."
      puts "#{@name}'s treasures: #{@found_treasures}"
    end

    def points
      @found_treasures.values.reduce(0, :+)
    end

    def each_found_treasure
      @found_treasures.each do |name, points|
        yield Treasure.new(name, points)
      end
    end

    def self.from_csv(csv_string)
      name, health = csv_string.split(',')
      Player.new(name, health.to_i)
    end
  end


  if __FILE__ == $0
    player = Player.new("moe")
    puts player.name
    puts player.health
    player.w00t
    puts player.health
    player.blam
    puts player.health
    puts player.score
  end
end
